@@ -3,7 +3,7 @@ use pyo3::prelude::*;
 use pyo3::types::*;
 use pyo3::{PyObjectProtocol, PySequenceProtocol};
 use tk::tokenizer::{Offsets, PaddingDirection};
-use tk::utils::truncation::TruncateDirection;
+use tk::utils::truncation::TruncationDirection;
 use tokenizers as tk;
 
 use crate::error::{deprecation_warning, PyError};
@@ -441,18 +441,23 @@ impl PyEncoding {
     ///     stride (:obj:`int`, defaults to :obj:`0`):
     ///         The length of previous content to be included in each overflowing piece
     ///
-    ///     direction (:obj:`str`, defaults to :obj:`right`)
+    ///     direction (:obj:`str`, defaults to :obj:`right`):
     ///         Truncate direction
     #[args(stride = "0")]
     #[args(direction = "\"right\"")]
     #[text_signature = "(self, max_length, stride=0, direction='right')"]
-    fn truncate(&mut self, max_length: usize, stride: usize, direction: &str) {
+    fn truncate(&mut self, max_length: usize, stride: usize, direction: &str) -> PyResult<()> {
         let tdir = match direction {
-            "left" => TruncateDirection::Left,
-            "right" => TruncateDirection::Right,
-            _ => panic!("Invalid truncation direction value : {}", direction),
-        };
+            "left" => Ok(TruncationDirection::Left),
+            "right" => Ok(TruncationDirection::Right),
+            _ => Err(PyError(format!(
+                "Invalid truncation direction value : {}",
+                direction
+            ))
+            .into_pyerr::<exceptions::PyValueError>()),
+        }?;
 
         self.encoding.truncate(max_length, stride, tdir);
+        Ok(())
     }
 }
