@@ -71,7 +71,7 @@ impl PyPostProcessor {
         let data = serde_json::to_string(self.processor.as_ref()).map_err(|e| {
             exceptions::PyException::new_err(format!(
                 "Error while attempting to pickle PostProcessor: {}",
-                e.to_string()
+                e
             ))
         })?;
         Ok(PyBytes::new(py, data.as_bytes()).to_object(py))
@@ -83,7 +83,7 @@ impl PyPostProcessor {
                 self.processor = serde_json::from_slice(s.as_bytes()).map_err(|e| {
                     exceptions::PyException::new_err(format!(
                         "Error while attempting to unpickle PostProcessor: {}",
-                        e.to_string()
+                        e
                     ))
                 })?;
                 Ok(())
