@@ -56,8 +56,8 @@ pub struct Lattice<'a> {
     nodes: Vec<NodeRef>,
     pub(super) begin_nodes: Vec<Vec<NodeRef>>,
     pub(super) end_nodes: Vec<Vec<NodeRef>>,
-    bos_id: usize,
-    eos_id: usize,
+    _bos_id: usize,
+    _eos_id: usize,
 }
 
 impl std::fmt::Display for Lattice<'_> {
@@ -158,8 +158,8 @@ impl<'a> Lattice<'a> {
             nodes,
             begin_nodes,
             end_nodes,
-            bos_id,
-            eos_id,
+            _bos_id: bos_id,
+            _eos_id: eos_id,
         }
     }
 
@@ -256,7 +256,7 @@ impl<'a> Lattice<'a> {
                     if node.borrow().id == self.bos_node().borrow().id {
                         let mut hypothesis = vec![];
                         let mut next: HypothesisRef =
-                            Rc::clone(&top.borrow().next.as_ref().unwrap());
+                            Rc::clone(top.borrow().next.as_ref().unwrap());
                         while next.borrow().next.is_some() {
                             hypothesis.push(next.borrow().node_ref.clone());
                             let c: HypothesisRef = next.clone();
@@ -325,7 +325,7 @@ impl<'a> Lattice<'a> {
         }
     }
     pub fn sentence(&self) -> &str {
-        &self.sentence
+        self.sentence
     }
 
     pub fn populate_marginal(&self, freq: f64, expected: &mut Vec<f64>) -> f64 {
