@@ -171,15 +171,21 @@ impl Model for WordLevel {
     type Trainer = WordLevelTrainer;
 
     fn tokenize(&self, token: &str) -> Result<Vec<Token>> {
-        Ok(vec![Token {
-            id: *self
-                .vocab
-                .get(&*token)
-                .or_else(|| self.vocab.get(&*self.unk_token))
-                .ok_or(Error::MissingUnkToken)?,
-            value: token.to_owned(),
-            offsets: (0, token.len()),
-        }])
+        if let Some(&id) = self.vocab.get(token) {
+            Ok(vec![Token {
+                id,
+                value: token.to_owned(),
+                offsets: (0, token.len()),
+            }])
+        } else if let Some(&unk_id) = self.vocab.get(&self.unk_token) {
+            Ok(vec![Token {
+                id: unk_id,
+                value: self.unk_token.to_owned(),
+                offsets: (0, token.len()),
+            }])
+        } else {
+            Err(Box::new(Error::MissingUnkToken))
+        }
     }
 
     fn token_to_id(&self, token: &str) -> Option<u32> {
@@ -220,3 +226,37 @@ impl Model for WordLevel {
         WordLevelTrainer::default()
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_tokenize_unk() {
+        let vocab: Vocab = [("<unk>".into(), 0), ("a".into(), 1), ("b".into(), 2)]
+            .iter()
+            .cloned()
+            .collect();
+        let wordlevel = WordLevelBuilder::default()
+            .vocab(vocab)
+            .unk_token("<unk>".to_string())
+            .build()
+            .unwrap();
+        let tokens = wordlevel.tokenize("c").unwrap();
+        assert_eq!(tokens, vec![Token::new(0u32, "<unk>".into(), (0, 1)),]);
+
+        let tokens = wordlevel.tokenize("a").unwrap();
+        assert_eq!(tokens, vec![Token::new(1u32, "a".into(), (0, 1)),]);
+    }
+
+    #[test]
+    fn test_tokenize_missing_unk_token() {
+        let vocab: Vocab = [("a".into(), 0), ("b".into(), 1)].iter().cloned().collect();
+        let wordlevel = WordLevelBuilder::default().vocab(vocab).build().unwrap();
+        let tokens = wordlevel.tokenize("a").unwrap();
+        assert_eq!(tokens, vec![Token::new(0u32, "a".into(), (0, 1)),]);
+
+        let error = wordlevel.tokenize("c").err().unwrap();
+        assert!(error.is::<Error>());
+    }
+}
