@@ -1,6 +1,7 @@
 use super::WordLevel;
 use crate::utils::parallelism::*;
 use crate::{AddedToken, Result, Trainer};
+use std::cmp::Ordering;
 use std::collections::HashMap;
 
 #[non_exhaustive]
@@ -40,7 +41,19 @@ impl WordLevelTrainer {
         model: &mut WordLevel,
     ) -> Result<Vec<AddedToken>> {
         let mut ordered_counts = word_counts.iter().collect::<Vec<_>>();
-        ordered_counts.sort_by_key(|(_, n)| std::cmp::Reverse(*n));
+
+        //sort the word counts first by inverse counts and then by word, in order
+        //to keep the sorting deterministic in case of equal counts
+        let cmp = |l: &(&String, &u32), r: &(&String, &u32)| -> Ordering {
+            let count_comp: Ordering = l.1.cmp(r.1);
+            if count_comp != Ordering::Equal {
+                return count_comp.reverse();
+            }
+            l.0.cmp(r.0)
+        };
+
+        ordered_counts.sort_by(cmp);
+
         let word_level = WordLevel::builder()
             .vocab(
                 self.special_tokens
